Computation times — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Computation times

00:03.017 total execution time for 4 files from examples05-other:

Example | Time | Mem (MB)
--- | --- | ---
Example of finding the bandgap (`plot_ebs.py`) | 00:02.069 | 0.0
Example of kpath_generator (`plot_kpath_generation.py`) | 00:00.449 | 0.0
Example of kmesh_generator (`plot_2dkmesh_generation.py`) | 00:00.380 | 0.0
Example of finding the bandgap (`plot_bandgap.py`) | 00:00.119 | 0.0